@@ -1,4 +1,18 @@
+#
+# This file is part of MooseX-CascadeClearing
+#
+# This software is Copyright (c) 2012 by Chris Weyl.
+#
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+#
 package MooseX::CascadeClearing;
+{
+  $MooseX::CascadeClearing::VERSION = '0.05';
+}
+
+# ABSTRACT: Cascade clearer actions across attributes
 
 use warnings;
 use strict;
@@ -12,20 +26,93 @@ use Carp;
 # debugging
 #use Smart::Comments '###', '####';
 
-Moose::Exporter->setup_import_methods;
+Moose::Exporter->setup_import_methods(
+    trait_aliases => [
+        [ 'MooseX::CascadeClearing::Role::Meta::Attribute' => 'CascadeClearing' ],
+    ],
+    class_metaroles => {
+        attribute => [
+            'MooseX::CascadeClearing::Role::Meta::Attribute',
+        ],
+    },
+    role_metaroles => {
+        applied_attribute => [
+            'MooseX::CascadeClearing::Role::Meta::Attribute',
+        ],
+    },
+);
+
+{
+    package MooseX::CascadeClearing::Role::Meta::Attribute;
+{
+  $MooseX::CascadeClearing::Role::Meta::Attribute::VERSION = '0.05';
+}
+    use namespace::autoclean;
+    use Moose::Role;
+
+    has clear_master    => (is => 'rw', isa => 'Str', predicate => 'has_clear_master');
+    has is_clear_master => (is => 'rw', isa => 'Bool', default => 0);
+
+    after install_accessors => sub {
+        my ($self, $inline) = @_;
+
+        ### in install_accessors, installing if: $self->is_clear_master
+        return unless $self->is_clear_master;
+
+
+        my $clearer = $self->clearer;
+        my $name    = $self->name;
+        my $att     = $self; # right??
+
+        confess "clear_master attribute '$name' MUST have a clearer defined!"
+            unless $self->has_clearer;
+
+        ### installing master clearer...
+        $self->associated_class->add_after_method_modifier($self->clearer, sub {
+            my $self = shift @_;
+
+            ### in clear_value...
+            return unless $att->is_clear_master;
+
+            ### looping over our attributes...
+            my @attributes = $self->meta->get_all_attributes;
+
+            for my $attr (@attributes) {
+
+                ### working on: $attr->name
+                # ->does() seems to be giving us weird results
+                if ($attr->can('clear_master')
+                    && $attr->has_clear_master
+                    && $attr->clear_master eq $name) {
+
+                    ### clearing...
+                    if (my $clearer = $attr->clearer) { $self->$clearer }
+                    else { $attr->clear_value($self)                    }
+                }
+            }
+        });
+    };
+}
+
+# can we prevent the clearer from being inlined?  Do we need to?  Are we?
+
+1;
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=for :stopwords Chris Weyl
 
 =head1 NAME
 
-MooseX::CascadeClearing - Cascade clearer actions across attributes 
+MooseX::CascadeClearing - Cascade clearer actions across attributes
 
 =head1 VERSION
 
-Version 0.02
-
-=cut
-
-our $VERSION = '0.04';
-
+This document describes version 0.05 of MooseX::CascadeClearing - released September 15, 2012 as part of MooseX-CascadeClearing.
 
 =head1 SYNOPSIS
 
@@ -39,11 +126,14 @@ our $VERSION = '0.04';
         is_clear_master => 1,
     );
 
-    my @opts = (
-        is => 'ro', isa => 'Str', clear_master => 'master', lazy_build => 1,
+    my @opts => (
+        is           => 'ro',
+        isa          => 'Str',
+        clear_master => 'master',
+        lazy_build   => 1,
     );
 
-    has sub1 => @opts; 
+    has sub1 => @opts;
     has sub2 => @opts;
     has sub3 => @opts;
 
@@ -52,7 +142,7 @@ our $VERSION = '0.04';
     sub _build_sub3 { shift->master . "3" }
 
     sub some_sub {
-        # ... 
+        # ...
 
         # clear master, sub[123] in one fell swoop
         $self->clear_master;
@@ -63,7 +153,7 @@ our $VERSION = '0.04';
 
 MooseX::CascadeClearing does the necessary metaclass fiddling to allow an
 clearing one attribute to be cascaded through to other attributes as well,
-calling their clearers.  
+calling their clear accessors.
 
 The intended purpose of this is to assist in situations where the value of one
 attribute is derived from the value of another attribute -- say a situation
@@ -74,6 +164,8 @@ this is trivial to do manually for a few attributes, once we consider
 subclassing and adding in roles the ability to "auto-clear", as it were, is
 a valuable trait.  (Sorry, couldn't resist.)
 
+=for Pod::Coverage init_meta
+
 =head1 CAVEAT
 
 We don't yet trigger a cascade clear on a master attribute's value being set
@@ -83,8 +175,8 @@ option in the not-too-distant-future.
 =head1 ATTRIBUTE OPTIONS
 
 We install an attribute metaclass trait that provides two additional
-atttribute options, as well as wraps the generated clearer method for a
-designated "master" attribute.  By default, use'ing this module causes this
+attribute options, as well as wraps the generated clearer method for a
+designated "master" attribute.  By default, using this module causes this
 trait to be installed for all attributes in the package.
 
 =over 4
@@ -94,7 +186,7 @@ trait to be installed for all attributes in the package.
 If set to 1, we wrap this attribute's clearer with a sub that looks for other
 attributes to clear.
 
-=item clear_master => Str
+=item clear_master => < attribute_name >
 
 Marks this attribute as one that should be cleared when the named attribute's
 clearer is called.  Note that no checking is done to ensure that the named
@@ -102,162 +194,30 @@ master is actually an attribute in the class.
 
 =back
 
-=cut
+=head1 SOURCE
 
-{
-    package MooseX::CascadeClearing::Role::Meta::Attribute;
-    use namespace::autoclean;
-    use Moose::Role;
-
-    has clear_master    => (is => 'rw', isa => 'Str', predicate => 'has_clear_master');
-    has is_clear_master => (is => 'rw', isa => 'Bool', default => 0);
-
-    after install_accessors => sub {  
-        my ($self, $inline) = @_;
-    
-        ### in install_accessors, installing if: $self->is_clear_master
-        return unless $self->is_clear_master;
-
-
-        my $clearer = $self->clearer;
-        my $name    = $self->name;
-        my $att     = $self; # right??
-
-        confess "clear_master attribute '$name' MUST have a clearer defined!"
-            unless $self->has_clearer;
-
-        ### installing master clearer...
-        $self->associated_class->add_after_method_modifier($self->clearer, sub { 
-            my $self = shift @_;
-        
-            ### in clear_value...
-            return unless $att->is_clear_master;
-
-            ### looping over our attributes...
-            my @attributes = $self->meta->get_all_attributes;
-    
-            for my $attr (@attributes) {
-            
-                ### working on: $attr->name
-                # ->does() seems to be giving us weird results
-                if ($attr->can('clear_master') 
-                    && $attr->has_clear_master 
-                    && $attr->clear_master eq $name) {
-                        
-                    ### clearing...
-                    if (my $clearer = $attr->clearer) { $self->$clearer }
-                    else { $attr->clear_value($self)                    }
-                }
-            }
-        });
-    };
-}
-
-# can we prevent the clearer from being inlined?  Do we need to?  Are we?
-
-sub init_meta {
-    shift;
-    my %options = @_;
-    my $for_class = $options{for_class};
-
-    ### in init_meta: $options{for_class} 
-    Moose->init_meta(%options)
-        unless Class::MOP::class_of($for_class);
-
-    my %metaroles = (
-        class_metaroles => {
-            attribute => ['MooseX::CascadeClearing::Role::Meta::Attribute'],
-        }
-    );
-
-    $metaroles{role_metaroles} = {
-        applied_attribute =>
-            ['MooseX::CascadeClearing::Role::Meta::Attribute'],
-        }
-        if $Moose::VERSION >= 1.9900;
-
-    Moose::Util::MetaRole::apply_metaroles(
-        for => $options{for_class},
-        %metaroles,
-    );
-
-    ### applied traits, returning...
-    return $for_class->meta;
-}
-
-=head1 AUTHOR
-
-Chris Weyl, C<< <cweyl at alumni.drew.edu> >>
+The development version is on github at L<http://github.com/RsrchBoy/moosex-cascadeclearing>
+and may be cloned from L<git://github.com/RsrchBoy/moosex-cascadeclearing.git>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to 
-C<bug-moosex-cascadeclearing at rt.cpan.org>, or through
-the web interface at 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-CascadeClearing>.  
-I will be notified, and then you'llautomatically be notified of progress 
-on your bug as I make changes.
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/moosex-cascadeclearing/issues
 
-=head1 SUPPORT
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc MooseX::CascadeClearing
+Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 COPYRIGHT AND LICENSE
 
-You can also look for information at:
+This software is Copyright (c) 2012 by Chris Weyl.
 
-=over 4
+This is free software, licensed under:
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MooseX-CascadeClearing>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/MooseX-CascadeClearing>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/MooseX-CascadeClearing>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/MooseX-CascadeClearing/>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-L<MooseX::AlwaysCoerce>, for inspiring me to do this in a slightly more sane
-fashion than I was previously.
-
-And of course the L<Moose> team, who have made my life significantly easier
-(and more fun!) since 0.17 :)
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2009, Chris Weyl C<< <cweyl@alumni.drew.edu> >>.
-
-This library is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free 
-Software Foundation; either version 2.1 of the License, or (at your option) 
-any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT 
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-OR A PARTICULAR PURPOSE.
-
-See the GNU Lesser General Public License for more details.  
-
-You should have received a copy of the GNU Lesser General Public License 
-along with this library; if not, write to the 
-
-    Free Software Foundation, Inc., 
-    59 Temple Place, Suite 330, 
-    Boston, MA  02111-1307 USA
+  The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-1; # End of MooseX::CascadeClearing
